.. _scripting_examples:

Examples
========

.. _`development demos`: https://github.com/jinningwang/ams/tree/master/dev/demo

Refer to the development `development demos`_ for examples prior to preparing this section.

A collection of examples are presented to supplement the tutorial. The
examples below are identical to the Jupyter Notebook in the ``examples``
folder of the repository
`here <https://github.com/CURENT/ams/tree/master/examples>`__.

.. toctree::
   :maxdepth: 2
   :caption: Scripting

   ../_examples/ex1.ipynb
   ../_examples/ex2.ipynb
   ../_examples/ex3.ipynb
   ../_examples/ex4.ipynb
   ../_examples/ex5.ipynb
   ../_examples/ex6.ipynb
   ../_examples/ex7.ipynb
